@@ -1,6 +1,6 @@
-__title__ = 'vishap.__init__'
-__version__ = '0.1'
-__build__ = 0x000001
+__title__ = 'vishap'
+__version__ = '0.1.1'
+__build__ = 0x000002
 __author__ = 'Artur Barseghyan'
 __all__ = ('render_video', 'get_registered_plugins', 'get_registered_plugin_uids', 'ensure_autodiscover')
 
