@@ -1,7 +1,7 @@
 __title__ = 'vishap.contrib.plugins.vimeo.vishap_plugin'
-__version__ = '0.1'
-__build__ = 0x000001
 __author__ = 'Artur Barseghyan'
+__copyright__ = 'Copyright (c) 2013 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('VimeoPlugin',)
 
 from vishap.base import BaseVideoPlugin, plugin_registry
